==> miktex-2.9.7250.tar.xz: miktex-2.9.7250/Admin/COM/guids.cmake <==
set(guid_MiKTeX_Package_Manager_206 "E4EC6D80-9E3A-47B7-ADA7-C0621C298527")
set(guid_MiKTeX_Package_Manager_TLB_206 "42542DAE-9AAF-41A0-A2FC-7F3CEEA9A5CB")
set(guid_MiKTeX_Session_206 "DE6D4D25-4E98-488D-91B2-E97CC319764B")
set(guid_MiKTeX_Session_TLB_206 "4C28CF19-0EC8-42AF-B901-CDCCCCE420FB")

set(guid_MiKTeX_Package_Manager_207 "77839C50-E196-4878-BAB5-83366DA54201")
set(guid_MiKTeX_Package_Manager_TLB_207 "D2EC0AB0-17F9-4815-A7E9-527BC3FF9745")
set(guid_MiKTeX_Session_207 "68783EAC-4655-49DB-97D6-E12A9EA29555")
set(guid_MiKTeX_Session_TLB_207 "8448CA35-07AF-4510-8381-3E96FC39FBF0")

set(guid_MiKTeX_Package_Manager_208 "80405147-9003-4E8C-88DE-4DCE92E1134A")
set(guid_MiKTeX_Package_Manager_TLB_208 "FF61470A-DC24-4526-9E7C-8B69AE558C7E")
set(guid_MiKTeX_Session_208 "5C27CDF6-3956-4A44-A3BE-B37A5730549D")
set(guid_MiKTeX_Session_TLB_208 "4376D3DF-049D-4471-9DF4-8D44819D3481")

set(guid_MiKTeX_Package_Manager_209 "25E664C9-989C-4EDA-A9A4-C9E45FB447D3")
set(guid_MiKTeX_Package_Manager_TLB_209 "676719BB-7737-43AA-9B7C-49C83644AE87")
set(guid_MiKTeX_Session_209 "A2662D75-3286-4A8D-8050-C0FD76393A31")
set(guid_MiKTeX_Session_TLB_209 "392BFC08-8CD2-487F-87EE-B2DA213BBD20")

set(guid_MiKTeX_Package_Manager_300 "314ACAB6-C939-40E8-89DA-605AB99D29FE")
set(guid_MiKTeX_Package_Manager_TLB_300 "AEFC46AF-2C29-4069-AD7F-ECCE37578353")
set(guid_MiKTeX_Session_300 "DF60C249-6A6C-4C09-8507-5A9B76FAF91A")
set(guid_MiKTeX_Session_TLB_300 "B5EE96E7-6040-4FB3-8FD1-3E4710D9D20C")

set(guid_MiKTeX_Package_Manager_CURVER ${guid_MiKTeX_Package_Manager_${MIKTEX_MAJOR_MINOR_INT}} )
set(guid_MiKTeX_Package_Manager_TLB_CURVER ${guid_MiKTeX_Package_Manager_TLB_${MIKTEX_MAJOR_MINOR_INT}} )
set(guid_MiKTeX_Session_CURVER ${guid_MiKTeX_Session_${MIKTEX_MAJOR_MINOR_INT}})
set(guid_MiKTeX_Session_TLB_CURVER ${guid_MiKTeX_Session_TLB_${MIKTEX_MAJOR_MINOR_INT}})

==> miktex-20.6.29.tar.xz: miktex-20.6.29/Admin/COM/guids.cmake <==
set(guid_MiKTeX_Package_Manager_206 "E4EC6D80-9E3A-47B7-ADA7-C0621C298527")
set(guid_MiKTeX_Package_Manager_TLB_206 "42542DAE-9AAF-41A0-A2FC-7F3CEEA9A5CB")
set(guid_MiKTeX_Session_206 "DE6D4D25-4E98-488D-91B2-E97CC319764B")
set(guid_MiKTeX_Session_TLB_206 "4C28CF19-0EC8-42AF-B901-CDCCCCE420FB")

set(guid_MiKTeX_Package_Manager_207 "77839C50-E196-4878-BAB5-83366DA54201")
set(guid_MiKTeX_Package_Manager_TLB_207 "D2EC0AB0-17F9-4815-A7E9-527BC3FF9745")
set(guid_MiKTeX_Session_207 "68783EAC-4655-49DB-97D6-E12A9EA29555")
set(guid_MiKTeX_Session_TLB_207 "8448CA35-07AF-4510-8381-3E96FC39FBF0")

set(guid_MiKTeX_Package_Manager_208 "80405147-9003-4E8C-88DE-4DCE92E1134A")
set(guid_MiKTeX_Package_Manager_TLB_208 "FF61470A-DC24-4526-9E7C-8B69AE558C7E")
set(guid_MiKTeX_Session_208 "5C27CDF6-3956-4A44-A3BE-B37A5730549D")
set(guid_MiKTeX_Session_TLB_208 "4376D3DF-049D-4471-9DF4-8D44819D3481")

set(guid_MiKTeX_Package_Manager_209 "25E664C9-989C-4EDA-A9A4-C9E45FB447D3")
set(guid_MiKTeX_Package_Manager_TLB_209 "676719BB-7737-43AA-9B7C-49C83644AE87")
set(guid_MiKTeX_Session_209 "A2662D75-3286-4A8D-8050-C0FD76393A31")
set(guid_MiKTeX_Session_TLB_209 "392BFC08-8CD2-487F-87EE-B2DA213BBD20")

set(guid_MiKTeX_Package_Manager_CURVER ${guid_MiKTeX_Package_Manager_${MIKTEX_COM_MAJOR_MINOR_INT}} )
set(guid_MiKTeX_Package_Manager_TLB_CURVER ${guid_MiKTeX_Package_Manager_TLB_${MIKTEX_COM_MAJOR_MINOR_INT}} )
set(guid_MiKTeX_Session_CURVER ${guid_MiKTeX_Session_${MIKTEX_COM_MAJOR_MINOR_INT}})
set(guid_MiKTeX_Session_TLB_CURVER ${guid_MiKTeX_Session_TLB_${MIKTEX_COM_MAJOR_MINOR_INT}})
